@@ -4,6 +4,7 @@ import os
 from forest.common import proc_utils
 
 cmake_command = 'cmake'
+default_args = list()
 
 def _construct(self, srcdir, builddir):
     self.srcdir = srcdir
@@ -13,12 +14,18 @@ def _is_configured(self):
 
     return os.path.exists(os.path.join(self.builddir, 'Makefile'))
 
+def _set_default_args(args):
+    global default_args
+    default_args = args
+
 def _configure(self, args):
 
+    print(f'default args: {default_args}')
+
     if args is None:
         args = list()
 
-    return _call_cmake([self.srcdir] + args, cwd=self.builddir)
+    return _call_cmake([self.srcdir] + args + default_args, cwd=self.builddir)
     
 
 def _build(self, target, jobs):
